@@ -82,7 +82,7 @@ def temp_settings(settings: BaseSettings, **update):
     :param update: Dictionary of settings values to add/update.
     """
     previous_settings = settings.dict()
-    update = {k.lower(): v for k, v in update.items()}
+    update = {k: v for k, v in update.items()}
     for k, v in update.items():
         settings.__setattr__(k, v)
     yield
